@@ -10,7 +10,10 @@
  * Statistics.  
  */
 
-#include <S.h>
+//  #include <S.h>                                  // VT::30.01.2022 - replace by R.h, a bug report from
+#include <R.h>                                      //  Prof. Ripley from 15.01.2022
+#define Salloc(n,t) (t*)S_alloc(n, sizeof(t))       // VT::30.01.2022
+
 #include "robust.h"
 #include <math.h>
 
@@ -52,7 +55,7 @@ void rl_rb_rand(Sfloat *X, Sfloat *y, Sint *N, Sint *P, Sint *M, Sfloat *ours,
 	Sfloat *Fi, *res, *res_s, *w, scale;
 	Sfloat *v, *v2, *v_aux, *yb;
 	Sfloat u, u2, s, c, Psi_constant, beta;
-	Sint n, p, m, seed, *indices;
+	Sint n, p, m, *indices;
 	register Sint i, j, k;
 
 	beta = *Beta;
@@ -61,7 +64,6 @@ void rl_rb_rand(Sfloat *X, Sfloat *y, Sint *N, Sint *P, Sint *M, Sfloat *ours,
 	n = *N;
 	p = *P;
 	m = *M;
-	seed = *Seed;
 
 	indices = Salloc(n, Sint);
 	v = Salloc(p, Sfloat);
@@ -219,7 +221,7 @@ void rl_rb_fixed(Sfloat *X, Sfloat *y, Sint *N, Sint *P, Sint *M, Sfloat *ours,
 	Sfloat *Fi, *res, *res_s, *w, scale;
 	Sfloat *v, *v2, *v_aux, *yb, beta;
 	Sfloat u, u2, s, c, Psi_constant;
-	Sint n, p, m, seed, *indices;
+	Sint n, p, m, *indices;
 	register Sint i, j;
 
 	beta = *Beta;
@@ -229,7 +231,6 @@ void rl_rb_fixed(Sfloat *X, Sfloat *y, Sint *N, Sint *P, Sint *M, Sfloat *ours,
 	n = *N;
 	p = *P;
 	m = *M;
-	seed = *Seed;
 
 	indices = Salloc(n, Sint);
 	v = Salloc(p, Sfloat);
@@ -522,18 +523,28 @@ void rl_sampler_i(Sint n, Sint *x)
    * x[i] = (Sint) ( (Sfloat) rand() / RAND_MAX * (Sfloat) (n-1) );
    */
 
-  long ignored = 0;
+  //    long ignored = 0;
+  
   Sint i = 0;
   Sfloat u = 0.0;
 
-  seed_in(&ignored);
+  // VT::30.01.2022 - replace S.h bu R.h
+  //    seed_in() and seed_out() will be repalced by GetRNGstate() 
+  //    and PutRNGstate(), respectively
+  
+  //    seed_in(&ignored);
+  
+  GetRNGstate();
 
   for(i = 0; i < n; i++) {
     u = unif_rand();
     x[i] = (Sint) (u * ((Sfloat) (n - 1)));
   }
 
-  seed_out(&ignored);
+  //    seed_out(&ignored);
+  
+  PutRNGstate();
+
 }
 
 
